function [b0,spec]=absorption_spec(g,T1,T2,CF,SW,points,ny,w1)
%
% Computes absorption spectrum for a species with g value g and relaxation
% times T1 (longitudinal) and T2 (transverse) in a field range about the
% center field CF with sweep width SW (both in mT), assuming a microwave
% frequency ny in GHz and an amplitude w1 (in MHz) The number of points 
% can also be selected
% the field axis b0 and the spectrum spec, according to Bloch equations
% (steady-state value) are supplied
%
% it is assumed that the field range corresponds to a minor varaiation in
% the resonant g value

mT2MHz=13.9962458*g; % conversion mT to MHz using CODATA value for Bohr magneton

b0=linspace(CF-SW/2,CF+SW/2,points);
resfield=ny*1e3/mT2MHz;

WS=(b0-resfield)*mT2MHz;

M0=[0,0,1];
M=M0;
t=5*max([T1 T2]); % sufficient integration time to achieve steady state
for k=1:points,
    M=evolve_Bloch(M,t,w1,WS(k),T1,T2);
    spec(k)=-M(2)+i*M(1);
end;