function [M2,sigmod]=evolve_Bloch_fieldmod(M1,t,w1,WS0,T1,T2,modamp,modfrq)
% Evolve magnetization vector M1 for time t (usec), assuming an m.w. field
% amplitude w1 (MHz), an resonance offset WS (MHz), a longitudinal
% relaxation time T1 (usec), and a transverse relaxation time T2 (usec)
% a field modulation is assumed that modulates the resonance frequency by
% amplitude modamp (peak-to-peak, in MHz) with frequency modfrq (in MHz)
% the results are a new magnetization vector M2 and the amplitude of signal
% modulation
% a predelay of 5 times max(T1,T2) is applied to bring the system to
% staeady state before measuring

tpre=5*max([T1,T2]);
tmod=1/modfrq; % period of field modulation
modnum=ceil(tpre/tmod);
tpre=modnum*tmod; % integer number of modulation cycles

modnum2=ceil(t/tmod);
if modnum<2, modnum=2; end;
t=modnum2*tmod;

dt=1e-3;
num=tpre/dt;
mod=cos(2*pi*modfrq*linspace(0,tpre,num));
WS=WS0+modamp*mod/2; % factor 1/2 because peak-to-peak

Mx=M1(1);
My=M1(2);
Mz=M1(3);
M0=1;

for k=1:num,
    Mx=Mx-dt*2*pi*WS(k)*My-dt*Mx/T2;
    My=My+dt*2*pi*WS(k)*Mx-dt*2*pi*w1*Mz-dt*My/T2;
    Mz=Mz+dt*2*pi*w1*My-dt*(Mz-M0)/T1;
end;

num=t/dt;
signal=zeros(1,num);
tax=linspace(0,t,num);
mod=cos(2*pi*modfrq*tax);
WS=WS0+modamp*mod;


for k=1:num,
    Mx=Mx-dt*2*pi*WS(k)*My-dt*Mx/T2;
    My=My+dt*2*pi*WS(k)*Mx-dt*2*pi*w1*Mz-dt*My/T2;
    Mz=Mz+dt*2*pi*w1*My-dt*(Mz-M0)/T1;
    signal(k)=-My;
end;

sigmod=sum(mod.*signal);

% figure(2); clf;
% plot(tax,signal,'k');
% hold on;
% plot(tax,mod);
% 
M2=[Mx My Mz];