function handles=run_CW_spec(handles)
%
% Computes absorption spectrum for a species with g value g and relaxation
% times T1 (longitudinal) and T2 (transverse) in a field range about the
% center field CF with sweep width SW (both in mT), assuming a microwave
% frequency ny in GHz and an amplitude w1 (in MHz) The number of points 
% can also be selected
% the field axis b0 and the spectrum spec, according to Bloch equations
% (steady-state value) are supplied
% field modulation with modulation amplitude modamp (mT) and modulation
% gain is a receiver gain factor
%
% it is assumed that the field range corresponds to a minor varaiation in
% the resonant g value

g=handles.g;
mT2MHz=13.9962458*g; % conversion G to MHz using CODATA value for Bohr magneton
T1=handles.T1;
T2=handles.T2;
CF=handles.CF;
SW=handles.SW;
points=handles.points;
ny=handles.ny;
mwattn=exp(log(10)*handles.attn/10); % conversion of dB attenuation to power aattenuation factor 
mwpower=handles.power/mwattn;
w1=mT2MHz*handles.power_conversion*sqrt(mwpower/handles.power);

modamp=handles.modamp;
modfrq=handles.modfrq;
gain=handles.internalGain*handles.gain;
noise=handles.noise;
b0=linspace(CF-SW/2,CF+SW/2,points);
spec=zeros(size(b0));
resfield=ny*1e3/mT2MHz;

axes(handles.spec_plot);
cla;
axis([min(b0),max(b0),-32768,32768]);
xlabel('Magnetic field (mT)');
hold on;

WS=(b0-resfield)*mT2MHz;

modamp=modamp*mT2MHz*handles.mod_calib; % conversion of modulation amplitude

disp(modamp);

M0=[0,0,1];
for scank=1:handles.scans,
    cla
    set(handles.status_line,'String',sprintf('%s%i%s%i%s','Acquiring scan ',scank,' out of ',handles.scans,' scans.'));
    M=M0;
    t=5*max([T1 T2]); % sufficient integration time to achieve steady state
    for k=1:points,
        [M,signal]=evolve_Bloch_fieldmod(M,t,w1,WS(k),T1,T2,modamp,modfrq);
        spec(k)=spec(k)+gain*(signal+noise*randn);
        if k>1,
            plot([b0(k-1) b0(k)],[spec(k-1)/scank spec(k)/scank],'b');
            drawnow;
        end;
    end;
end;

handles.b0=b0;
handles.spec=spec/handles.scans;